#
# spec file for package python-plyvel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global skip_python2 1
Name:           python-plyvel
Version:        1.5.1
Release:        1.2
Summary:        Python interface to LevelDB
License:        BSD-3-Clause
Group:          Productivity/Networking/Other
URL:            https://plyvel.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/p/plyvel/plyvel-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.17}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  leveldb-devel >= 1.21
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Plyvel is a Python interface to LevelDB.

In addition to basic features like getting, putting and deleting
data, Plyvel allows you to use write batches, database snapshots,
very flexible iterators, prefixed databases, bloom filters, custom
cache sizes, custom comparators.

%prep
%setup -q -n plyvel-%{version}
mkdir tests

%build
%python_build

%install
%python_install
%fdupes %{buildroot}

%check
mv plyvel plyvel.hide
%pytest_arch

%files %{python_files}
%license LICENSE.rst
%doc doc NEWS.rst README.rst
%{python_sitearch}/*

%changelog
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
  * Add Python 3.12 support
  * Rebuild Linux wheels, including Python 3.12 wheels.
  * Allow using plyvel.DB as a context manager (pr #151)
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.5.0
  * use manylinux2014 image for building wheels
  * Fix typo in docs (#145)
  * update leveldb links to github
  * clarify bloom_filter_bits in docs
  * skip py36 wheels
  * drop py36 from tox config
* Sun Jan 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Build Linux wheels against Snappy 1.1.9, LevelDB 1.22
  * The minimum LevelDB version is now 1.21
  * Add support for :py:meth:`WriteBatch.append()`
  * Add support for :py:meth:`WriteBatch.approximate_size()`
  * Use manylinux2010 instead of manylinux1 to build wheels
  * Add Python 3.9 support
  * Drop Python 3.5 support
  * Completely drop Python 2 support
* Thu May 27 2021 pgajdos@suse.com
- %%check: do not call setup.py test, use %%pytest_arch macro
* Wed Mar 18 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.2.0
  * Add Python 3.8 support
  * Drop Python 3.4 support
* Mon May 20 2019 pgajdos@suse.com
- version update to 1.1.0
  * Expose :py:attr:`~DB.name` attribute to Python code
    (`pr #90 <https://github.com/wbolster/plyvel/pull/90>`_)
* Thu Oct 11 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.5:
  * Rebuild wheels: build against Snappy 1.1.7, and produce Python
    3.7 wheels
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 1.0.4:
  * No relevant change for package users
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 1.0.0:
  * First 1.x release. This library is quite mature, so there is
    no reason to keep using 0.x version numbers. While at it,
    switch to semantic versioning.
  * Drop support for older Python versions. Minimum versions are
    now Python 3.4+ for modern Python and Python 2.7+ for legacy
    Python.
  * The mimimum LevelDB version is now 1.20, which added an option
    for the maximum file size, which is now exposed in Plyvel.
  * The various .put() methods are no longer restricted to just
    bytes (str in Python 2), but will accept any type implementing
    Python's buffer protocol, such as bytes, bytearray, and
    memoryview. Note that this only applies to values; keys must
    still be bytes. (issue #52)
* Wed Jun 21 2017 jengelh@inai.de
- Trim filler wording from description and replace by a
  substantiated feature list.
* Sun Jun 11 2017 mpluskal@suse.com
- Switch to python singlespec
* Sun Jan 31 2016 mpluskal@suse.com
- Enable tests
- Update dependencies
* Tue Oct 28 2014 mpluskal@suse.com
- Initial package
